@@ -13,7 +13,7 @@ class NetworkError(Exception):
 class Cache(objects.Object):
 	def __init__(self, path=None):
 		if path == None: path = f"{HOME}/.cache/"
-		if not gfp.exists(path): os.mkdir(path)
+		if not Files.exists(path): Files.create(path, directory=True)
 		objects.Object.__init__(self)
 		self.assign({
 			"path":path,
@@ -76,13 +76,13 @@ class WebServer(objects.Thread):
 		id="webserver",
 		host="127.0.0.1",
 		port=52379,
-		path=None,
+		path=None, # only used for tokens, rest is stored in python memory only.
 		default={},
 		# do not use.
 		serialized={},
 	):
 		objects.Thread.__init__(self)
-		self.__cache__ = Cache(path=path)
+		self.__cache__ = Cache(path=path) # only used for tokens, rest is stored in python memory only.
 		self.default = dict(default)
 		self.assign({
 			"sleeptime":3,
@@ -91,7 +91,7 @@ class WebServer(objects.Thread):
 			"port":port,
 			"cache":default,
 		})
-		self.assign(serialized)
+		self.assign(serialized, keys=["sleeptime", "id", "host", "port", "cache"], safe=True)
 		self.id = id.replace(" ","-")
 		self.tag = self.id.replace(" ","_")
 		try: self.log_level
@@ -114,7 +114,7 @@ class WebServer(objects.Thread):
 			response = self.__serialize__(response.json())
 		except:
 			return r3sponse.error(f"Failed to serialize {response}: {response.text}")
-		return r3sponse.safe_response(response)
+		return r3sponse.response(response, safe=True)
 	def get(self, group=None, id=None, timeout=3):
 		encoded = urllib.parse.urlencode({
 			"group":group.replace(" ","_"),
@@ -131,7 +131,7 @@ class WebServer(objects.Thread):
 			response = self.__serialize__(response.json())
 		except:
 			return r3sponse.error(f"Failed to serialize {response}: {response.text}")
-		return r3sponse.safe_response(response)
+		return r3sponse.response(response, safe=True)
 	# flask app.
 	def app(self):
 		app = flask.Flask(__name__)
@@ -201,9 +201,10 @@ class WebServer(objects.Thread):
 			print(f"Starting the {self.id}.")
 		serialized = self.dict()
 		serialized["path"] = self.__cache__.path
-		for i in ["__cache__","cache",]:
-			del serialized[i]
-		serialized = json.dumps(self.__serialize__(serialized, safe=True),indent=0)
+		for i in ["__cache__","cache","_stder", "_traceback_", "_name", "_daemonic", "_ident", "_native_id", "_tstate_lock", "_started", "_stderr", "_initialized", "_invoke_excepthook", "__status__", "__running__", "__response__", "_is_stopped", "_args", "_kwargs", "_target", "_raw_traceback_",]:
+			try: del serialized[i]
+			except: a=1
+		serialized = f"{serialized}"
 		command = [defaults.vars.python3, f"{SOURCE_PATH}classes/cache/fork.py", "--serialized", f"'{serialized}'", "--syst3m-webserver-tag", self.tag]
 		if self.log_level < 0:
 			command += [ "2>", "/dev/null"]
@@ -271,20 +272,44 @@ class WebServer(objects.Thread):
 		except requests.exceptions.ConnectionError:
 			return False
 	# system functions.
-	def __serialize__(self, dict, safe=False):
-		for key in list(dict.keys()):
-			value = dict[key]
-			if value in ["False", "false"]: dict[key] = False
-			elif value in ["True", "true"]: dict[key] = True
-			elif value in ["None", "none", "null", "nan"]: dict[key] = None
-			else:
-				try: 
-					int(value)
-					dict[key] = int(value)
-				except: a=1
-			if safe and isinstance(value, object):
-				del dict[key]
-		return dict
+	def __serialize__(self, dictionary, safe=False):
+		if isinstance(dictionary, (Dictionary, dict)):
+			new = {}
+			for key, value in dictionary.items():
+				if value in ["False", "false"]: new[key] = False
+				elif value in ["True", "true"]: new[key] = True
+				elif value in ["None", "none", "null", "nan"]: new[key] = None
+				elif isinstance(value, (dict, Dictionary, list, Array)):
+					new[key] = self.__serialize__(value, safe=safe)
+				elif isinstance(value, object):
+					if not safe:
+						new[key] = value
+				else:
+					try: 
+						int(value)
+						new[key] = int(value)
+					except: 
+						new[key] = value
+			return new
+		if isinstance(dictionary, (Dictionary, dict)):
+			new = []
+			for value in dictionary:
+				if value in ["False", "false"]: new.append(False)
+				elif value in ["True", "true"]: new.append(True)
+				elif value in ["None", "none", "null", "nan"]: new.append(None)
+				elif isinstance(value, (dict, Dictionary)):
+					new.append(self.__serialize__(value, safe=safe))
+				elif isinstance(value, object):
+					if not safe:
+						new.append(value)
+				else:
+					try: 
+						int(value)
+						new.append(int(value))
+					except: 
+						new.append(value)
+			return new
+		else: raise ValueError(f"Parameter [dictionary] requires to be a [dict, Dictionary, list, Array], not [{dictionary.__class__.__name__}].")
 	#def stop(self):
 	#	self.process.terminate()
 	#	self.process.join()
