@@ -42,7 +42,7 @@ def __check_alias__(
 	path = f"{base}/{alias}"
 	overwrite = "--overwrite" in sys.argv
 	if (("--force" in sys.argv or "--forced" in sys.argv or overwrite) and present) or (present or not os.path.exists(str(path))):
-		file = f"""#!/usr/bin/env python3\nimport os, sys\npackage="{executable}"\nsys.argv.pop(0)\narguments = sys.argv\ns = ""\nfor i in arguments:\n	if s == "": \n		if " " in i: s = "'"+i+"'"\n		else: s = i\n	else: \n		if " " in i: s += " '"+i+"'"\n		else: s += " "+i\nif os.path.exists("/usr/bin/python3"): os.system("/usr/bin/python3 "+package+" "+s)\nelse:  os.system("python3 "+package+" "+s)"""
+		file = f"""#!/usr/bin/env python3\nimport os, sys\npackage="{executable}"\nsys.argv.pop(0)\narguments = sys.argv\ns = ""\nfor i in arguments:\n	if s == "": \n		if " " in i: s = "'"+i+"'"\n		else: s = i\n	else: \n		if " " in i: s += " '"+i+"'"\n		else: s += " "+i\nif os.path.exists("/usr/bin/python3"): os.system("/usr/bin/python3 "+package+" "+s)\nelse:  os.system("python3 "+package+" "+s)\n#os.system("python3 "+package+" "+s)"""
 		sudo = Boolean("--sudo" in sys.argv).string(true="sudo ",false="")
 		os.system(f"{sudo}touch {path}")
 		os.system(f"{sudo}chmod +x {path}")
@@ -79,11 +79,8 @@ try:
 
 # download.
 except ImportError as e:
-	import os
-	if os.path.exists("/usr/bin/pip3"): 
-		os.system(f"/usr/bin/pip3 install -r {FilePath(__file__).base(back=3)}/requirements/requirements.pip --user {os.environ.get('USER')}")
-	else:
-		os.system(f"pip3 install -r {FilePath(__file__).base(back=3)}/requirements/requirements.pip")
+	import syst3m
+	syst3m.defaults.install_requirements(f"{sys.executable} -m pip install -r {FilePath(__file__).base(back=3)}/requirements/requirements.pip")
 
 	# pip imports.
 	import os, sys, requests, ast, json, pathlib, glob, platform, subprocess, time, random, threading, urllib, flask, logging, multiprocessing
