@@ -67,15 +67,63 @@ class Object(Traceback):
 			dictionary[key] = value
 		return dictionary
 	# assign self variables by dictionary.
-	def assign(self, dictionary, serialize=True):
+	def assign(self, 
+		# the dictionary to self assign.
+		dictionary, 
+		# serialize dictionary from str to object.
+		serialize=True,
+		# the keys to get from the dict.
+		keys=["*"],
+		# safe disabled throws an error when one of the specified keys does not exist.
+		safe=True,
+	):
 		if not isinstance(dictionary, dict):
 			raise TypeError("You can only self assign with a dictionary as parameter.")
-		for key,value in dictionary.items():
-			if serialize:
-				if value in ["True", "true", "TRUE"]: value = True
-				elif value in ["False", "false", "FALSE"]: value = False
-				elif value in ["None", "none", "null"]: value = None
-			self[key] = value
+		if not isinstance(keys, (dict, Dictionary, list, Array) ):
+			raise TypeError(f"Parameter [keys] requiers to be a [dict, Dictionary, list, Array] not [{keys.__class__.__name__}].")
+		# safe dict keys.
+		if isinstance(keys, (dict, Dictionary)):
+			for key,value in keys.items():
+				skip = False
+				if safe:
+					try:
+						dict_value = dictionary[key]
+					except:
+						dict_value = value
+						skip = False
+				else:
+					dict_value = dictionary[key]
+				if not skip:
+					if serialize:
+						if dict_value in ["True", "true", "TRUE"]: dict_value = True
+						elif dict_value in ["False", "false", "FALSE"]: dict_value = False
+						elif dict_value in ["None", "none", "null"]: dict_value = None
+					self[key] = dict_value
+		# array keys.
+		if isinstance(keys, (list, Array)) and "*" not in keys:
+			for key in keys:
+				skip = False
+				if safe:
+					try:
+						dict_value = dictionary[key]
+					except:
+						skip = True
+				else:
+					dict_value = dictionary[key]
+				if not skip:
+					if serialize:
+						if dict_value in ["True", "true", "TRUE"]: dict_value = True
+						elif dict_value in ["False", "false", "FALSE"]: dict_value = False
+						elif dict_value in ["None", "none", "null"]: dict_value = None
+					self[key] = dict_value
+		# all keys from dict.
+		else:
+			for key,value in dictionary.items():
+				if serialize:
+					if value in ["True", "true", "TRUE"]: value = True
+					elif value in ["False", "false", "FALSE"]: value = False
+					elif value in ["None", "none", "null"]: value = None
+				self[key] = value
 	# get attributes.
 	def attributes(self, keys=[]):
 		return self.dict(keys=keys)
@@ -129,39 +177,105 @@ class Thread(Object, threading.Thread):
 			if self.running: break
 			time.sleep(sleeptime)
 		if not self.running: 
-			self.response = r3sponse.error(f"Unable to start thread {self}.", log_level=self.log_level, required_log_level=0)
+			self.__response__ = r3sponse.error(f"Unable to start thread {self}.", log_level=self.log_level, required_log_level=0)
 			return self.response
-		self.response = r3sponse.success(f"Stopped thread {self.id}.", log_level=self.log_level, required_log_level=0)
+		self.__response__ = r3sponse.success(f"Stopped thread {self.id}.", log_level=self.log_level, required_log_level=0)
 		return self.response
 	def safe_stop(self, timeout=120, sleeptime=1):
 		r3sponse.log(f"Stopping thread {self.id}.", log_level=self.log_level, required_log_level=0)
-		try:
-			response = self.__stop__()
-		except AttributeError: response = None
-		if response != None:
-			try: success = bool(response["success"])
-			except: success = True
-			if not success: 
-				r3sponse.log(response=response, log_level=self.log_level, required_log_level=0)
-				self.response = response
-				return self.response
 		self.send_stop()
 		for i in range(timeout/sleeptime):
 			if self.stopped: break
 			time.sleep(sleeptime)
 		if not self.stopped: 
-			self.response = r3sponse.error(f"Unable to stop thread {self}.", log_level=self.log_level, required_log_level=0)
+			self.__response__ = r3sponse.error(f"Unable to stop thread {self}.", log_level=self.log_level, required_log_level=0)
 			return self.response
-		self.response = r3sponse.success(f"Stopped thread {self.id}.", log_level=self.log_level, required_log_level=0)
+		found = False
+		try:
+			response = self.stop()
+			found = True
+		except AttributeError: response = None
+		if not found:
+			try:
+				response = self.__stop__()
+				found = True
+			except AttributeError: response = None
+		if response != None:
+			try: success = bool(response["success"])
+			except: success = True
+			if not success: 
+				r3sponse.log(response=response, log_level=self.log_level, required_log_level=0)
+				self.__response__ = response
+				return self.response
+		self.__response__ = r3sponse.success(f"Stopped thread {self.id}.", log_level=self.log_level, required_log_level=0)
 		return self.response
-	def send_stop(self, response=None):
-		if response != None:
+	def send_stop(self, 
+		# all optional.
+		# option 1: the success message.
+		message=None, # (1)
+		args={}, # (2)
+		# option 2: the error message.
+		error=None,
+		# option 3: the response object.
+		response=None, 
+		# save the message/error/response.
+		save=False,
+		# the active log level.
+		log_level=1,
+		# the required log level for when to print to console (leave None to use r3sponse.log_level ; default: 0).
+		required_log_level=r3sponse.log_level,
+	):
+		if message != None:
+			self.__response__ = r3sponse.success(message, args)
+			msg = message
+		elif error != None:
+			self.__response__ = r3sponse.error(error)
+			msg = error
+		elif response != None:
 			self.__response__ = response
+			if response["success"]:
+				msg = response["message"]
+			else:
+				msg = response["error"]
 		self.__status__ = "stopping"
-	def send_crash(self, response=None):
-		if response != None:
+		if log_level >= required_log_level or save:
+			r3sponse.log(message=message, error=error, response=response, save=save, log_level=log_level, required_log_level=required_log_level)
+		return self.__response__
+		#
+	def send_crash(self, 
+		# all optional.
+		# option 1: the success message.
+		message=None, # (1)
+		args={}, # (2)
+		# option 2: the error message.
+		error=None,
+		# option 3: the response object.
+		response=None, 
+		# save the message/error/response.
+		save=False,
+		# the active log level.
+		log_level=1,
+		# the required log level for when to print to console (leave None to use r3sponse.log_level ; default: 0).
+		required_log_level=r3sponse.log_level,
+	):
+		if message != None:
+			self.__response__ = r3sponse.success(message, args)
+			msg = message
+		elif error != None:
+			self.__response__ = r3sponse.error(error)
+			msg = error
+		elif response != None:
 			self.__response__ = response
+			if response["success"]:
+				msg = response["message"]
+			else:
+				msg = response["error"]
 		self.__status__ = "crashed"
+		if log_level >= required_log_level or save:
+			r3sponse.log(message=message, error=error, response=response, save=save, log_level=log_level, required_log_level=required_log_level)
+		return self.__response__
+		#
+
 	#properties
 	@property
 	def run_permission(self):
