@@ -77,7 +77,7 @@ class Service(objects.Object):
 	def create(self):
 
 		# check params.
-		response = r3sponse.check_parameters(
+		response = r3sponse.parameters.check(
 			traceback=self.__traceback__(function="create"),
 			parameters={
 				"id":self.id,
@@ -106,7 +106,7 @@ class Service(objects.Object):
 	def check(self):
 
 		# check params.
-		response = r3sponse.check_parameters(
+		response = r3sponse.parameters.check(
 			traceback=self.__traceback__(function="check"),
 			parameters={
 				"id":self.id,
